<?php
/*
Plugin Name: WPshore 301 Redirects
Contributors: nablasol
Plugin URI: http://www.wpshore.com/plugins
Description: Create a list of URLs that you would like to 301 redirect to another page or site
Donate link: http://www.wpshore.com/services
Tags: 301, seo, redirect, url
Version: 1.0
Author: Nablasol
Author URI: http://www.nablasol.com/
Requires at least: 3.0
Tested up to: 3.5.2
Stable tag: 1.0
License: GPLv2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html

*/


if (!class_exists("WPshore301Redirects")) {
	class WPshore301Redirects {
		/*
			generate the link to the options page under settings
		*/
		function create_menu()
		{
		  add_options_page('WPshore Redirects', 'WPshore Redirects', 10, 'WPshoreoptions', array($this,'options_page'));
		}
		
		/*
			generate the options page in the wordpress admin
		*/
		function options_page()
		{
		?>
		
<script type="text/javascript" src=" https://ajax.googleapis.com/ajax/libs/jquery/1.7.1/jquery.min.js"></script>
 
		<script type="text/javascript">
		$('.addnew').live('click', function(){
		var thisRow = $(this).parent().parent();
		newRow = thisRow.clone(true).insertAfter(thisRow);
		newRow.find('input:not(.add)').val("");

				$(this).removeClass('addnew').addClass('remove');
					$(this).val("-");
					newRow.find('input.increment').val(parseInt(thisRow.find('input.increment').val())+1);
				});

				$('.remove').live('click', function(){
					$(this).parent().parent().remove();
				});
		</script>

		<div class="wrap">
		<h2>WPshore Redirects</h2>
		
		<form method="post" action="options-general.php?page=WPshoreoptions">
		
		<table>
			<tr>
				<th>Request</th>
				<th>Destination</th>
			</tr>
			<tr>
				<td><small>example: /about.htm</small></td>
				<td><small>example: <?php echo get_option('home'); ?>/about/</small></td>
			</tr>
			<?php echo $this->extend_redirects(); ?>
			<tr>
				<td><input type="text" name="WPshore_redirects[request][]" value="" style="width:15em" />&nbsp;&raquo;&nbsp;</td>
				<td><input type="text" name="WPshore_redirects[destination][]" value="" style="width:30em;" /></td>
				<td><input type="button" class="addnew add" value="+" /></td> 
			</tr>
		</table>
		
		<p class="submit">
		<input type="submit" name="submit_WPshore" class="button-primary" value="<?php _e('Save Changes') ?>" />
		</p>
		</form>
		</div>
		<?php
		} // end of function options_page
		
		/*
			utility function to return the current list of redirects as form fields
		*/
		function extend_redirects(){
			$wpshoreredirects = get_option('WPshore_redirects');
			$output = '';
			if (!empty($wpshoreredirects)) {
				foreach ($wpshoreredirects as $request => $destination) {
					$output .= '
					
					<tr>
						<td><input type="text" name="WPshore_redirects[request][]" value="'.$request.'" style="width:15em" />&nbsp;&raquo;&nbsp;</td>
						<td><input type="text" name="WPshore_redirects[destination][]" value="'.$destination.'" style="width:30em;" /></td>
						<td><input type="button" class="addnew add" value="+" /></td>
					</tr>
					
					';
				}
			} // end if
			return $output;
		}
		
		/*
			save the redirects from the options page to the database
		*/
		function save_WPshore_redirects($data)
		{
			$wpshoreredirects = array();
			
			for($i = 0; $i < sizeof($data['request']); ++$i) {
				$request = trim($data['request'][$i]);
				$destination = trim($data['destination'][$i]);
			
				if ($request == '' && $destination == '') { continue; }
				else { $wpshoreredirects[$request] = $destination; }
			}

			update_option('WPshore_redirects', $wpshoreredirects);
		}
		
		/*
			Read the list of redirects and if the current page 
			is found in the list, send the visitor on her way
		*/
		function redirects()
		{
			// this is what the user asked for (strip out home portion, case insensitive)
			$userrequest = str_ireplace(get_option('home'),'',$this->getPATH());
			$userrequest = rtrim($userrequest,'/');
			
			$wpshoreredirects = get_option('WPshore_redirects');
			if (!empty($wpshoreredirects)) {
				foreach ($wpshoreredirects as $storedrequest => $destination) {
					// compare user request to each 301 stored in the db
					if(urldecode($userrequest) == rtrim($storedrequest,'/')) {
						header ('HTTP/1.1 301 Moved Permanently');
						header ('Location: ' . $destination);
						exit();
					}
					else { unset($wpshoreredirects); }
				}
			}
		} // end funcion redirect
		
		/*
			utility function to get the full address of the current request
			
		*/
		function getPATH()
		{
			/*** check for https ***/
			$protocol = $_SERVER['HTTPS'] == 'on' ? 'https' : 'http';
			/*** return the full address ***/
			return $protocol.'://'.$_SERVER['HTTP_HOST'].$_SERVER['REQUEST_URI'];
		}
		
	} 
	
} // end check for existance of class

// instantiate
$redirect_plugin = new WPshore301Redirects();

if (isset($redirect_plugin)) {
	// add the redirect action, high priority
	add_action('init', array($redirect_plugin,'redirects'), 1);

	// create the menu
	add_action('admin_menu', array($redirect_plugin,'create_menu'));

	// if submitted, process the data
	if (isset($_POST['submit_WPshore'])) {
		$redirect_plugin->save_WPshore_redirects($_POST['WPshore_redirects']);
	}
}

// this is here for php4 compatibility
if(!function_exists('str_ireplace')){
  function str_ireplace($search,$replace,$subject){
    $token = chr(1);
    $haystack = strtolower($subject);
    $needle = strtolower($search);
    while (($pos=strpos($haystack,$needle))!==FALSE){
      $subject = substr_replace($subject,$token,$pos,strlen($search));
      $haystack = substr_replace($haystack,$token,$pos,strlen($search));
    }
    $subject = str_replace($token,$replace,$subject);
    return $subject;
  }
}
?>
